import React, { PureComponent } from 'react';
import { AutoSizer, List } from 'react-virtualized';
import withScrolling, {
  createVerticalStrength,
  createHorizontalStrength,
} from 'react-dnd-scrollzone';
import AdainTreeHeader from './AdainTreeHeader';

class AdainTree extends React.Component {
  constructor(props, context) {
	super(props, context);

	this.state = {
	  data: this.props.data || [],
	  listHeight: 300,
	  listRowHeight: 50,
	  overscanRowCount: 10,
	  rowCount: this.props.data ? this.props.data.length : 0,
	  scrollToIndex: undefined,
	  showScrollingPlaceholder: false
	};
  }

  componentWillMount(){
	console.log("componentWillMount");
  }
  
  componentDidMount(){
	console.log("componentDidMount");
  }
  
  shouldComponentUpdate(nextProps, nextState){
	console.log("shouldComponentUpdate: " + JSON.stringify(nextProps) + " " + JSON.stringify(nextState));
	return true;
  }
  
  componentWillUpdate(nextProps, nextState){
	console.log("componentWillUpdate: " + JSON.stringify(nextProps) + " " + JSON.stringify(nextState));
  }
  
  render () {
	const {
	  listHeight,
	  listRowHeight,
	  overscanRowCount,
	  rowCount,
	  scrollToIndex,
	  showScrollingPlaceholder,
	  useDynamicRowHeight
	} = this.state;
	let containerStyle = { height: '100%' };
	
	console.log(this);

	return (
		<div style={containerStyle}>
		  <AdainTreeHeader header={this.props.header}/>
		  <AutoSizer disableHeight>
			{({ width }) => (
				<List
					ref='List'
					height={listHeight}
					overscanRowCount={overscanRowCount}
					noRowsRenderer={this._noRowsRenderer.bind(this)}
					rowCount={rowCount}
					rowHeight={listRowHeight}
					rowRenderer={this._rowRenderer.bind(this)}
					scrollToIndex={scrollToIndex}
					width={width}
				/>
			)}
		  </AutoSizer>
		</div>
	);
  }

  search() {

  }

  moveNode() {
    
  }
  
  startDrag({path}) {
    
  }
  
  dragHover({ node: draggedNode, depth, minimumTreeIndex }) {
    
  }
  
  endDrag(dropResult) {
    
  }

  _rowRenderer({index, isScrolling, key, style}) {
	return (
		<div
			key={key}
			style={style}
			onClick={this._onClick.bind(this)}
		>
		  {this.props.data[index].name}
		</div>
	);
  }

  _noRowsRenderer() {
    return (
    	<div>
		  No rows
		</div>  
	);
  }
  
  _onClick(item) {
	console.log('on click', item);
    console.log('on click', this.props);
  }

  _onRowCountChange (event) {
	const rowCount = parseInt(event.target.value, 10) || 0;

	this.setState({ rowCount });
  }

  _onScrollToRowChange (event) {
	const { rowCount } = this.state;
	let scrollToIndex = Math.min(rowCount - 1, parseInt(event.target.value, 10));

	if (isNaN(scrollToIndex)) {
	  scrollToIndex = undefined;
	}

	this.setState({ scrollToIndex });
  }
}

export default AdainTree;
